Dialects — SQLAlchemy 0.7 Documentation

# SQLAlchemy 0.7 Documentation

Search:
Release: 0.7.10 | Release Date: February 7, 2013

# Dialects

The dialect is the system SQLAlchemy uses to communicate with various types of DBAPIs and databases. A compatibility chart of supported backends can be found at Supported Databases. The sections that follow contain reference documentation and notes specific to the usage of each backend, as well as notes for the various DBAPIs.

Note that not all backends are fully ported and tested with current versions of SQLAlchemy. The compatibility chart should be consulted to check for current support level.

- Drizzle
- Firebird
- Informix
- MaxDB
- Microsoft Access
- Microsoft SQL Server
- MySQL
- Oracle
- PostgreSQL
- SQLite
- Sybase